dataExpenseFlow: Get data about a set of government functions used as support...

View source: R/dataExpenseFlow.R

dataExpenseFlowR Documentation

Get data about a set of government functions used as support for sankey graphs

Description

Get data about a set of government functions used as support for sankey graphs

Usage

dataExpenseFlow(year = 2020)

Arguments

year

number

Value

data for sankey graph.

Examples

dataExpenseFlow(year=2020)

tchiluanda/Rcofog documentation built on July 1, 2022, 8:53 p.m.