View source: R/graphEconomicSubFunction.R
| graphEconomicSubFunction | R Documentation |
Generate a ranking graph for economic classification for government sub-function
graphEconomicSubFunction(.data, free_scale = TRUE)
.data |
tibble |
free_scale |
boolean. Indicates if the graph will be presented in free scale |
ranking graph.
dataEconomicSubFunction(year=2020) %>% graphEconomicSubFunction()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.