graphGovernmentAction: Generate a distribution graph for a given dataset

View source: R/graphGovernmentAction.R

graphGovernmentActionR Documentation

Generate a distribution graph for a given dataset

Description

Generate a distribution graph for a given dataset

Usage

graphGovernmentAction(.data, cluster = NULL, action = "Juros")

Arguments

.data

tibble

cluster

number that identifies the clusters to be shown at the graph

action

vector that identifies the government action to be highlighted

Value

jitter graph.

Examples

defineActionCluster(year=2020) %>% graphGovernmentAction()

tchiluanda/Rcofog documentation built on July 1, 2022, 8:53 p.m.