graphYearlyDistributionPercentage: Generate a time series graph for top government functions

View source: R/graphYearlyDistributionPercentage.R

graphYearlyDistributionPercentageR Documentation

Generate a time series graph for top government functions

Description

Generate a time series graph for top government functions

Usage

graphYearlyDistributionPercentage(.data)

Arguments

.data

tibble

Value

time series graph.

Examples

dataYearlyDistributionPercentage() %>% graphYearlyDistributionPercentage()

tchiluanda/Rcofog documentation built on July 1, 2022, 8:53 p.m.