View source: R/graphGovernmentAction.R
| graphGovernmentAction | R Documentation |
Generate a distribution graph for a given dataset
graphGovernmentAction(.data, cluster = NULL, action = "Juros")
.data |
tibble |
cluster |
number that identifies the clusters to be shown at the graph |
action |
vector that identifies the government action to be highlighted |
jitter graph.
defineActionCluster(year=2020) %>% graphGovernmentAction()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.